Fix clean builds when WITH_TESTS is enabled.

The addition of the TESTS knob and its enabling of the build of tests in
lib/libcrypt/tests/ broke the build.  The reason is that we cannot descend
into tests/ subdirectories until all prerequisites have been built, which
in the case of tests may be "a lot of things" (libatf-c in this case).

Ensure that we do not walk tests/ directories during the bootstrapping of
the libraries as part of buildworld.

Index: src/Makefile.inc1
===================================================================
--- src.orig/Makefile.inc1
+++ src/Makefile.inc1
@@ -1585,10 +1585,12 @@ ${_lib}__PL: .PHONY .MAKE
 .if exists(${.CURDIR}/${_lib})
 	${_+_}@${ECHODIR} "===> ${_lib} (obj,depend,all,install)"; \
 		cd ${.CURDIR}/${_lib} && \
-		${MAKE} DIRPRFX=${_lib}/ obj && \
-		${MAKE} DIRPRFX=${_lib}/ depend && \
-		${MAKE} -DNO_PROFILE -DNO_PIC DIRPRFX=${_lib}/ all && \
-		${MAKE} -DNO_PROFILE -DNO_PIC DIRPRFX=${_lib}/ install
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET obj && \
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET depend && \
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET -DNO_PROFILE \
+		    -DNO_PIC all && \
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET -DNO_PROFILE \
+		    -DNO_PIC install
 .endif
 .endfor
 
@@ -1597,10 +1599,10 @@ ${_lib}__L: .PHONY .MAKE
 .if exists(${.CURDIR}/${_lib})
 	${_+_}@${ECHODIR} "===> ${_lib} (obj,depend,all,install)"; \
 		cd ${.CURDIR}/${_lib} && \
-		${MAKE} DIRPRFX=${_lib}/ obj && \
-		${MAKE} DIRPRFX=${_lib}/ depend && \
-		${MAKE} DIRPRFX=${_lib}/ all && \
-		${MAKE} DIRPRFX=${_lib}/ install
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET obj && \
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET depend && \
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET all && \
+		${MAKE} DIRPRFX=${_lib}/ -D_NO_TESTS_YET install
 .endif
 .endfor
 
@@ -1610,10 +1612,12 @@ ${_lib}__L: .PHONY .MAKE
 lib/libpam__L: .PHONY .MAKE
 	${_+_}@${ECHODIR} "===> lib/libpam (obj,depend,all,install)"; \
 		cd ${.CURDIR}/lib/libpam && \
-		${MAKE} DIRPRFX=lib/libpam/ obj && \
-		${MAKE} DIRPRFX=lib/libpam/ depend && \
-		${MAKE} DIRPRFX=lib/libpam/ -D_NO_LIBPAM_SO_YET all && \
-		${MAKE} DIRPRFX=lib/libpam/ -D_NO_LIBPAM_SO_YET install
+		${MAKE} DIRPRFX=lib/libpam/ -D_NO_TESTS_YET obj && \
+		${MAKE} DIRPRFX=lib/libpam/ -D_NO_TESTS_YET depend && \
+		${MAKE} DIRPRFX=lib/libpam/ -D_NO_TESTS_YET \
+		    -D_NO_LIBPAM_SO_YET all && \
+		${MAKE} DIRPRFX=lib/libpam/ -D_NO_TESTS_YET \
+		    -D_NO_LIBPAM_SO_YET install
 
 _prereq_libs: ${_prereq_libs:S/$/__PL/}
 _startup_libs: ${_startup_libs:S/$/__L/}
Index: src/share/mk/bsd.own.mk
===================================================================
--- src.orig/share/mk/bsd.own.mk
+++ src/share/mk/bsd.own.mk
@@ -556,6 +556,13 @@ MK_CLANG_FULL:= no
 MK_LLDB:= no
 .endif
 
+.if defined(_NO_TESTS_YET)
+# At the beginning of a fresh buildworld, we must ensure that we don't
+# descend into any tests/ subdirectories until we have built all the
+# necessary dependent libraries.
+MK_TESTS:= no
+.endif
+
 #
 # Set defaults for the MK_*_SUPPORT variables.
 #
